==> xwiki-platform-template-api-9.0-sources.jar: org/xwiki/template/event/AbstractTemplateEvent.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.template.event;

import java.util.Objects;

/**
 * Base class for all events related to templates.
 *
 * @version $Id: b92b93e7ec3fec4072be71a15d94dad9f7019a8d $
 * @since 7.0M1
 */
public abstract class AbstractTemplateEvent implements TemplateEvent
{
    private String id;

    /**
     * Matches any {@link TemplateEvent}s.
     */
    public AbstractTemplateEvent()
    {

    }

    /**
     * @param id the id of the template
     */
    public AbstractTemplateEvent(String id)
    {
        this.id = id;
    }

    @Override
    public boolean matches(Object otherEvent)
    {
        if (getClass() == otherEvent.getClass()) {
            return Objects.equals(this.id, ((TemplateEvent) otherEvent).getId());
        }

        return false;
    }

    @Override
    public String getId()
    {
        return this.id;
    }
}

==> xwiki-platform-template-api-10.8-sources.jar: org/xwiki/template/event/AbstractTemplateEvent.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.template.event;

import java.util.Objects;

/**
 * Base class for all events related to templates.
 *
 * @version $Id: a76191ec4f5c8259dda15ccb8bcaab84cc0a8f3e $
 * @since 7.0M1
 */
public abstract class AbstractTemplateEvent implements TemplateEvent
{
    private String id;

    /**
     * Matches any {@link TemplateEvent}s.
     */
    public AbstractTemplateEvent()
    {

    }

    /**
     * @param id the id of the template
     */
    public AbstractTemplateEvent(String id)
    {
        this.id = id;
    }

    @Override
    public boolean matches(Object otherEvent)
    {
        if (getClass() == otherEvent.getClass()) {
            return this.id == null || Objects.equals(this.id, ((TemplateEvent) otherEvent).getId());
        }

        return false;
    }

    @Override
    public String getId()
    {
        return this.id;
    }
}
